@@ -3,18 +3,8 @@ use warnings;
 use strict;
 use JSON::Create 'create_json';
 my %example = (
-    down => {
-	and => {
-	    down => {
-		and => {
-		    down => {
-			and => {
-			    down => 'we go'
-			}
-		    }
-		}
-	    }
-	}
-    },
+    x => 1,
+    y => 2,
+    z => 3,
 );
 print create_json (\%example);
